@@ -1,7 +1,7 @@
 from .lpi_filter import *
 from .ctmf import median_filter
-from .canny import canny
+from ._canny import canny
 from .edges import sobel, hsobel, vsobel, hprewitt, vprewitt, prewitt
-from .tv_denoise import tv_denoise
-from .rank_order import rank_order
+from ._tv_denoise import tv_denoise
+from ._rank_order import rank_order
 from .thresholding import threshold_otsu, threshold_adaptive
