@@ -24,13 +24,13 @@ All rights reserved.
 Original author: Lee Kamentsky
 """
 
-from _heapq import heapify, heappush, heappop
+from _heapq import heappush, heappop
 import numpy as np
 import scipy.ndimage
 from ..filter import rank_order
 
 from . import _watershed
-import warnings
+
 
 def watershed(image, markers, connectivity=None, offset=None, mask=None):
     """
@@ -87,8 +87,8 @@ def watershed(image, markers, connectivity=None, offset=None, mask=None):
 
     This implementation converts all arguments to specific, lowest common
     denominator types, then passes these to a C algorithm.
-    
-    Markers can be determined manually, or automatically using for example 
+
+    Markers can be determined manually, or automatically using for example
     the local minima of the gradient of the image, or the local maxima of the
     distance function to the background for separating overlapping objects
     (see example).
@@ -122,28 +122,28 @@ def watershed(image, markers, connectivity=None, offset=None, mask=None):
     The algorithm works also for 3-D images, and can be used for example to
     separate overlapping spheres.
     """
-    
+
     if connectivity == None:
         c_connectivity = scipy.ndimage.generate_binary_structure(image.ndim, 1)
     else:
         c_connectivity = np.array(connectivity, bool)
         if c_connectivity.ndim != image.ndim:
-            raise ValueError,"Connectivity dimension must be same as image"
+            raise ValueError("Connectivity dimension must be same as image")
     if offset == None:
-        if any([x%2==0 for x in c_connectivity.shape]):
-            raise ValueError,"Connectivity array must have an unambiguous \
-            center"
+        if any([x % 2 == 0 for x in c_connectivity.shape]):
+            raise ValueError("Connectivity array must have an unambiguous "
+                    "center")
         #
         # offset to center of connectivity array
         #
         offset = np.array(c_connectivity.shape) // 2
 
-    # pad the image, markers, and mask so that we can use the mask to 
+    # pad the image, markers, and mask so that we can use the mask to
     # keep from running off the edges
     pads = offset
 
     def pad(im):
-        new_im = np.zeros([i + 2*p for i, p in zip(im.shape, pads)], im.dtype)
+        new_im = np.zeros([i + 2 * p for i, p in zip(im.shape, pads)], im.dtype)
         new_im[[slice(p, -p, None) for p in pads]] = im
         return new_im
 
@@ -157,18 +157,17 @@ def watershed(image, markers, connectivity=None, offset=None, mask=None):
     c_image = rank_order(image)[0].astype(np.int32)
     c_markers = np.ascontiguousarray(markers, dtype=np.int32)
     if c_markers.ndim != c_image.ndim:
-        raise ValueError,\
-            "markers (ndim=%d) must have same # of dimensions "\
-            "as image (ndim=%d)"%(c_markers.ndim, cimage.ndim)
+        raise ValueError("markers (ndim=%d) must have same # of dimensions "
+                         "as image (ndim=%d)" % (c_markers.ndim, c_image.ndim))
     if c_markers.shape != c_image.shape:
         raise ValueError("image and markers must have the same shape")
     if mask != None:
         c_mask = np.ascontiguousarray(mask, dtype=bool)
         if c_mask.ndim != c_markers.ndim:
-            raise ValueError, "mask must have same # of dimensions as image"
+            raise ValueError("mask must have same # of dimensions as image")
         if c_markers.shape != c_mask.shape:
-            raise ValueError, "mask must have same shape as image"
-        c_markers[np.logical_not(mask)]=0
+            raise ValueError("mask must have same shape as image")
+        c_markers[np.logical_not(mask)] = 0
     else:
         c_mask = None
     c_output = c_markers.copy()
@@ -189,9 +188,8 @@ def watershed(image, markers, connectivity=None, offset=None, mask=None):
         indexes = []
         ignore = True
         for j in range(len(c_connectivity.shape)):
-            elems = c_image.shape[j]
-            idx   = (i // multiplier) % c_connectivity.shape[j]
-            off   = idx - offset[j]
+            idx = (i // multiplier) % c_connectivity.shape[j]
+            off = idx - offset[j]
             if off:
                 ignore = False
             offs.append(off)
@@ -214,10 +212,10 @@ def watershed(image, markers, connectivity=None, offset=None, mask=None):
         else:
             c_mask = c_mask.astype(np.int8).flatten()
         _watershed.watershed(c_image.flatten(),
-                             pq, age, c, 
-                             c_image.ndim, 
+                             pq, age, c,
+                             c_image.ndim,
                              c_mask,
-                             np.array(c_image.shape,np.int32),
+                             np.array(c_image.shape, np.int32),
                              c_output)
     c_output = c_output.reshape(c_image.shape)[[slice(1, -1, None)] *
                                                 image.ndim]
@@ -230,18 +228,18 @@ def watershed(image, markers, connectivity=None, offset=None, mask=None):
 def is_local_maximum(image, labels=None, footprint=None):
     """
     Return a boolean array of points that are local maxima
- 
+
     Parameters
     ----------
     image: ndarray (2-D, 3-D, ...)
         intensity image
-        
-    labels: ndarray, optional 
+
+    labels: ndarray, optional
         find maxima only within labels. Zero is reserved for background.
-    
+
     footprint: ndarray of bools, optional
         binary mask indicating the neighborhood to be examined
-        `footprint` must be a matrix with odd dimensions, the center is taken 
+        `footprint` must be a matrix with odd dimensions, the center is taken
         to be the point in question.
 
     Returns
@@ -263,7 +261,7 @@ def is_local_maximum(image, labels=None, footprint=None):
     array([[ True, False, False, False],
            [ True, False,  True, False],
            [ True, False, False, False],
-           [ True,  True, False,  True]], dtype='bool')
+           [ True,  True, False,  True]], dtype=bool)
     >>> image = np.arange(16).reshape((4, 4))
     >>> labels = np.array([[1, 2], [3, 4]])
     >>> labels = np.repeat(np.repeat(labels, 2, axis=0), 2, axis=1)
@@ -281,7 +279,7 @@ def is_local_maximum(image, labels=None, footprint=None):
     array([[False, False, False, False],
            [False,  True, False,  True],
            [False, False, False, False],
-           [False,  True, False,  True]], dtype='bool')
+           [False,  True, False,  True]], dtype=bool)
     """
     if labels is None:
         labels = np.ones(image.shape, dtype=np.uint8)
@@ -289,7 +287,7 @@ def is_local_maximum(image, labels=None, footprint=None):
         footprint = np.ones([3] * image.ndim, dtype=np.uint8)
     assert((np.all(footprint.shape) & 1) == 1)
     footprint = (footprint != 0)
-    footprint_extent = (np.array(footprint.shape)-1) // 2
+    footprint_extent = (np.array(footprint.shape) - 1) // 2
     if np.all(footprint_extent == 0):
         return labels > 0
     result = (labels > 0).copy()
@@ -297,17 +295,17 @@ def is_local_maximum(image, labels=None, footprint=None):
     # Create a labels matrix with zeros at the borders that might be
     # hit by the footprint.
     #
-    big_labels = np.zeros(np.array(labels.shape) + footprint_extent*2,
+    big_labels = np.zeros(np.array(labels.shape) + footprint_extent * 2,
                           labels.dtype)
-    big_labels[[slice(fe,-fe) for fe in footprint_extent]] = labels
+    big_labels[[slice(fe, -fe) for fe in footprint_extent]] = labels
     #
     # Find the relative indexes of each footprint element
     #
     image_strides = np.array(image.strides) // image.dtype.itemsize
     big_strides = np.array(big_labels.strides) // big_labels.dtype.itemsize
     result_strides = np.array(result.strides) // result.dtype.itemsize
-    footprint_offsets = np.mgrid[[slice(-fe,fe+1) for fe in footprint_extent]]
-    
+    footprint_offsets = np.mgrid[[slice(-fe, fe + 1) for fe in footprint_extent]]
+
     fp_image_offsets = np.sum(image_strides[:, np.newaxis] *
                               footprint_offsets[:, footprint], 0)
     fp_big_offsets = np.sum(big_strides[:, np.newaxis] *
@@ -315,9 +313,9 @@ def is_local_maximum(image, labels=None, footprint=None):
     #
     # Get the index of each labeled pixel in the image and big_labels arrays
     #
-    indexes = np.mgrid[[slice(0,x) for x in labels.shape]][:, labels > 0]
+    indexes = np.mgrid[[slice(0, x) for x in labels.shape]][:, labels > 0]
     image_indexes = np.sum(image_strides[:, np.newaxis] * indexes, 0)
-    big_indexes = np.sum(big_strides[:, np.newaxis] * 
+    big_indexes = np.sum(big_strides[:, np.newaxis] *
                          (indexes + footprint_extent[:, np.newaxis]), 0)
     result_indexes = np.sum(result_strides[:, np.newaxis] * indexes, 0)
     #
@@ -335,18 +333,15 @@ def is_local_maximum(image, labels=None, footprint=None):
         same_label = (big_labels_raveled[big_indexes + fp_big_offset] ==
                       big_labels_raveled[big_indexes])
         less_than = (image_raveled[image_indexes[same_label]] <
-                     image_raveled[image_indexes[same_label]+ fp_image_offset])
+                     image_raveled[image_indexes[same_label] + fp_image_offset])
         result_raveled[result_indexes[same_label][less_than]] = False
-        
+
     return result
 
 
-
 # ---------------------- deprecated ------------------------------
-# Deprecate slower pure-Python code, that we keep only for 
+# Deprecate slower pure-Python code, that we keep only for
 # pedagogical purposes
-
-
 def __heapify_markers(markers, image):
     """Create a priority queue heap with the markers on it"""
     stride = np.array(image.strides) // image.itemsize
@@ -354,24 +349,25 @@ def __heapify_markers(markers, image):
     ncoords = coords.shape[0]
     if ncoords > 0:
         pixels = image[markers != 0]
-        age    = np.arange(ncoords)
+        age = np.arange(ncoords)
         offset = np.zeros(coords.shape[0], int)
         for i in range(image.ndim):
             offset = offset + stride[i] * coords[:, i]
         pq = np.column_stack((pixels, age, offset, coords))
         # pixels = top priority, age=second
-        ordering = np.lexsort((age, pixels)) 
+        ordering = np.lexsort((age, pixels))
         pq = pq[ordering, :]
     else:
         pq = np.zeros((0, markers.ndim + 3), int)
     return (pq, ncoords)
-    
+
+
 def _slow_watershed(image, markers, connectivity=8, mask=None):
     """Return a matrix labeled using the watershed algorithm
-    
+
     Use the `watershed` function for a faster execution.
     This pure Python function is solely for pedagogical purposes.
-    
+
     Parameters
     ----------
     image: 2-d ndarray of integers
@@ -380,16 +376,16 @@ def _slow_watershed(image, markers, connectivity=8, mask=None):
     markers: 2-d ndarray of integers
         a two-dimensional matrix marking the basins with the values
         to be assigned in the label matrix. Zero means not a marker.
-    connectivity: {4, 8}, optional 
+    connectivity: {4, 8}, optional
         either 4 for four-connected or 8 (default) for eight-connected
-    mask: 2-d ndarray of bools, optional    
+    mask: 2-d ndarray of bools, optional
         don't label points in the mask
 
-    Returns 
+    Returns
     -------
     out: ndarray
         A labeled matrix of the same type and shape as markers
-    
+
 
     Notes
     -----
@@ -409,20 +405,20 @@ def _slow_watershed(image, markers, connectivity=8, mask=None):
 
     This implementation converts all arguments to specific, lowest common
     denominator types, then passes these to a C algorithm.
-    
-    Markers can be determined manually, or automatically using for example 
+
+    Markers can be determined manually, or automatically using for example
     the local minima of the gradient of the image, or the local maxima of the
     distance function to the background for separating overlapping objects.
     """
     if connectivity not in (4, 8):
         raise ValueError("Connectivity was %d: it should be either \
-        four or eight" %(connectivity))
-    
+        four or eight" % (connectivity))
+
     image = np.array(image)
     markers = np.array(markers)
     labels = markers.copy()
-    max_x  = markers.shape[0]
-    max_y  = markers.shape[1]
+    max_x = markers.shape[0]
+    max_y = markers.shape[1]
     if connectivity == 4:
         connect_increments = ((1, 0), (0, 1), (-1, 0), (0, -1))
     else:
